==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-6e.js <==
dispMUA.arDispMUAAllocation["n"] =
{
  "notonebit.com simple mailer" : [ "notonebit_com.png" , "http://www.notonebit.com/" ] ,
  "network solutions webmail" : [ "networksolutions.png" , "http://www.networksolutions.com/" ] ,
  "netikus.net eventsentry" : [ "eventsentry.png" , "http://www.eventsentry.com/" ] ,
  "netmail modweb module" : [ "netmail.png" ] ,
  "nuralstorm webmail" : [ "nuralstorm.png" ] ,
  "nbb-rekenprogramma" : [ "nbb-rekenprogramma.png" ] ,
  "navigon newsmailer" : [ "navigon.png" , "http://www.navigon.com/" ] ,
  "newsletter genius" : [ "newsletter_genius.png" ] ,
  "nateon web mailer" : [ "nateon.png" ] ,
  "ni-mailer-skript" : [ "ni-mailer.png" , "http://www.n-image.com/" ] ,
  "netfirms mailing" : [ "netfirms_com.png" , "http://www.netfirms.com/" ] ,
  "neotonic trakken" : [ "neotonic.png" ] ,
  "nomad mime mail" : [ "nomad_mimemail.png" , "http://www.developarts.com/nomad_mimemail" ] ,
  "nms - 1:1 mail!" : [ "nms.png" ] ,
  "nexus mime mail" : [ "nexus_mimemail.png" , "http://www.developarts.com/nomad_mimemail" ] ,
  "newsletter pro" : [ "newsletter_pro.png" , "http://www.aborange.de/products/newsletter.php" ] ,
  "nwp mailrelay" : [ "nwp.png" , "http://www.netzwerkplan.de/" ] ,
  "newsoffice.de" : [ "newsoffice_de.png" , "http://www.newsoffice.de/" ] ,
  "nettalk email" : [ "nettalk.png" ] ,
  "nms formmail" : [ "nms-formmail.png" ] ,
  "newzcrawler" : [ "newzcrawler.png" ] ,
  "newsman pro" : [ "newsman_pro.png" ] ,
  "newsleecher" : [ "newsleecher.png" ] ,
  "newscoaster" : [ "newscoaster.png" , "http://newscoaster.tripod.com/" ] ,
  "newsbin pro" : [ "newsbin_pro.png" ] ,
  "news xpress" : [ "news_xpress.png" ] ,
  "nomad news" : [ "nomadnews.png" ] ,
  "newsportal" : [ "newsportal.png" ] ,
  "news rover" : [ "newsrover.png" ] ,
  "netcologne" : [ "netcologne.png" , "http://www.netcologne.de/" ] ,
  "ngtmailer" : [ "ngtmailer.png" , "http://www.ngt.no/" ] ,
  "newshound" : [ "newshound.png" ] ,
  "nyt-post" : [ "new_york_times.png" ] ,
  "nwebmail" : [ "nwebmail.png" , "http://nwebmail.sourceforge.net/" ] ,
  "noworyta" : [ "noworyta.png" ] ,
  "netscape" : [ "netscape.png" ] ,
  "newzbin" : [ "newzbin.png" ] ,
  "newspro" : [ "newspro.png" ] ,
  "netflix" : [ "netflix.png" ] ,
  "neomail" : [ "neomail.png" ] ,
  "nlsend" : [ "defacto.software.png" , "http://defacto-software.de/" ] ,
  "neu.de" : [ "neu_de.png" , "http://www.neu.de/" ] ,
  "naja/" : [ "naja.png" ] ,
  "npop" : [ "npop.png" ] ,
  "nocc" : [ "nocc.png" ] ,
  "nail" : [ "nail.png" ] ,
  "nu/" : [ "nusphere.png" , "http://www.nusphere.com/" ] ,
  "nn/" : [ "nn.png" ] ,
  "nn " : [ "nn.png" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-6e.js <==
dispMUA.arDispMUAAllocation["n"] =
{
  "notonebit.com simple mailer" : [ "notonebit_com.png" , "http://www.notonebit.com/" ] ,
  "network solutions webmail" : [ "networksolutions.png" , "http://www.networksolutions.com/" ] ,
  "netikus.net eventsentry" : [ "eventsentry.png" , "http://www.eventsentry.com/" ] ,
  "netmail modweb module" : [ "netmail.png" ] ,
  "nuralstorm webmail" : [ "nuralstorm.png" , "http://www.nuralstorm.net/" ] ,
  "network automation" : [ "networkautomation_com.png" , "http://www.networkautomation.com/" ] ,
  "nbb-rekenprogramma" : [ "nbb-rekenprogramma.png" ] ,
  "navigon newsmailer" : [ "navigon.png" , "http://www.navigon.com/" ] ,
  "newsletter genius" : [ "newsletter_genius.png" ] ,
  "nateon web mailer" : [ "nateon.png" ] ,
  "ni-mailer-skript" : [ "ni-mailer.png" , "http://www.n-image.com/" ] ,
  "netfirms mailing" : [ "netfirms_com.png" , "http://www.netfirms.com/" ] ,
  "neotonic trakken" : [ "neotonic.png" ] ,
  "nomad mime mail" : [ "nomad_mimemail.png" , "http://www.developarts.com/nomad_mimemail" ] ,
  "nms - 1:1 mail!" : [ "nms.png" ] ,
  "nexus mime mail" : [ "nexus_mimemail.png" , "http://www.developarts.com/nomad_mimemail" ] ,
  "newsletter pro" : [ "newsletter_pro.png" , "http://www.aborange.de/products/newsletter.php" ] ,
  "nwp mailrelay" : [ "nwp.png" , "http://www.netzwerkplan.de/" ] ,
  "newsoffice.de" : [ "newsoffice_de.png" , "http://www.newsoffice.de/" ] ,
  "nettalk email" : [ "nettalk.png" ] ,
  "nms formmail" : [ "nms-formmail.png" ] ,
  "newzcrawler" : [ "newzcrawler.png" ] ,
  "newsman pro" : [ "newsman_pro.png" ] ,
  "newsleecher" : [ "newsleecher.png" ] ,
  "newscoaster" : [ "newscoaster.png" , "http://newscoaster.tripod.com/" ] ,
  "newsbin pro" : [ "newsbin_pro.png" ] ,
  "news xpress" : [ "news_xpress.png" ] ,
  "nomad news" : [ "nomadnews.png" ] ,
  "newsportal" : [ "newsportal.png" ] ,
  "news rover" : [ "newsrover.png" ] ,
  "netcologne" : [ "netcologne.png" , "http://www.netcologne.de/" ] ,
  "ngtmailer" : [ "ngtmailer.png" , "http://www.ngt.no/" ] ,
  "newshound" : [ "newshound.png" ] ,
  "nyt-post" : [ "new_york_times.png" ] ,
  "nwebmail" : [ "nwebmail.png" , "http://nwebmail.sourceforge.net/" ] ,
  "noworyta" : [ "noworyta.png" ] ,
  "noson.it" : [ "noscon_it.png" , "http://listserver.noscon.it/" ] ,
  "netscape" : [ "netscape.png" , "http://netscape.aol.com/" ] ,
  "nourish" : [ "nourish.png" , "http://nouri.sh/" ] ,
  "newzbin" : [ "newzbin.png" ] ,
  "newspro" : [ "newspro.png" ] ,
  "netflix" : [ "netflix.png" ] ,
  "neomail" : [ "neomail.png" ] ,
  "nlsend" : [ "defacto.software.png" , "http://defacto-software.de/" ] ,
  "neu.de" : [ "neu_de.png" , "http://www.neu.de/" ] ,
  "naja/" : [ "naja.png" ] ,
  "npop" : [ "npop.png" ] ,
  "nocc" : [ "nocc.png" ] ,
  "nail" : [ "nail.png" ] ,
  "nu/" : [ "nusphere.png" , "http://www.nusphere.com/" ] ,
  "nn/" : [ "nn.png" ] ,
  "nn " : [ "nn.png" ] ,
}
